@@ -1,5 +1,4 @@
 import {ServerConnection} from '@jupyterlab/services';
-import axios from "axios";
 import { KernelSpecAPI } from '@jupyterlab/services';
 
 interface Configuration {
@@ -136,9 +135,6 @@ export const GET_PYKERNEL = async (): Promise<string> => {
   return pykernel
 }
 
-export var CancelToken = axios.CancelToken;
-export var source = CancelToken.source();
-
 // Global variables
 export class Globals {
   public static TOKENS: Map<string, string> = new Map<string, string>();
