@@ -1,7 +1,6 @@
 /* eslint-disable @typescript-eslint/no-empty-function */
 import { Widget } from '@lumino/widgets';
 import { Dialog, showDialog, Spinner } from '@jupyterlab/apputils';
-import { source } from './config';
 
 /**
  * A widget that holds the loading spinner
@@ -26,12 +25,28 @@ export const show_spinner = (message:string): void => {
     body: spinWidget,
     buttons: [Dialog.cancelButton()]
   })
+};
+
+export const showStandaloneSpinner = (message:string): Promise<any> => {
+  const spinWidget = new SpinnerDialog();
+  return showDialog({
+    title: message,
+    body: spinWidget,
+    buttons: []
+  })
+};
+
+export const showConfirmationStatus = (message:string): Promise<any> => {
+  return showDialog({
+    title: message,
+    body: "Are you sure you want to publish? This action is not reversible",
+    buttons: [Dialog.okButton(), Dialog.cancelButton()]
+  })
     .then(result => {
       if (!result.button.accept){
-        source.cancel('Operation cancelled by the user.');
+        throw new Error('Operation cancelled by the user.');
       }
     })
-    .catch(error => {});
 };
 
 /**
@@ -40,7 +55,7 @@ export const show_spinner = (message:string): void => {
 export const showSuccessPublishDialog = (): void => {
   showDialog({
     title: 'Success!',
-    body: 'This lab was successfully submitted for publishing!',
+    body: 'This lab has been successfully published!',
     buttons: [Dialog.okButton()]
   })
     .then(result => {})
