@@ -1,10 +1,9 @@
 /* eslint-disable no-async-promise-executor */
 import { AxiosError, AxiosInstance } from 'axios';
-import { show_spinner, showSuccessPublishDialog, showFailurePublishDialog } from './dialog';
+import { showStandaloneSpinner, showConfirmationStatus, showSuccessPublishDialog, showFailurePublishDialog } from './dialog';
 import { Dialog } from '@jupyterlab/apputils';
 import { ATLAS_BASE_URL } from './config';
 import axios from 'axios';
-import { source } from './config';
 
 export const axiosHandler = (lab_token: string): AxiosInstance => {
   const atlasClient = axios.create({
@@ -49,13 +48,14 @@ export const postLabModel = async (
   axiosHandler: AxiosInstance,
   labModel: string
 ): Promise<void> => {
-  show_spinner('Publishing your lab onto Skills Network...');
+  let confirmation_status = await showConfirmationStatus('Publishing your lab onto Skills Network...').then((resolve: any) => true).catch((err: any) => false);
+  if (!confirmation_status) return;
+  showStandaloneSpinner("Publishing your changes...");
+
   return new Promise<void>(async (resolve, reject) => {
     await axiosHandler
       .post('v1/labs', {
         body: labModel
-      },{
-        cancelToken: source.token,
       })
       .then(res => {
         console.log('SUCCESSFULLY PUSHED', res);
