@@ -2,13 +2,11 @@ import { JupyterFrontEnd, JupyterFrontEndPlugin } from '@jupyterlab/application'
 import { IMainMenu } from '@jupyterlab/mainmenu';
 import { Menu, Widget } from '@lumino/widgets';
 import { Dialog, showDialog } from '@jupyterlab/apputils';
-import { INotebookTracker, NotebookPanel,   } from '@jupyterlab/notebook';
+import { INotebookTracker } from '@jupyterlab/notebook';
 import { IDocumentManager } from '@jupyterlab/docmanager';
 import { show_spinner, showFailureImportLabDialog } from '../dialog';
-import { getLabFileName, loadLabContents } from '../tools';
-import { axiosHandler, getLabModel } from '../handler';
-import * as nbformat from '@jupyterlab/nbformat';
-import { Globals, MODE } from '../config';
+import { MODE } from '../config';
+import { openLab } from '../tools';
 
 export const menu: JupyterFrontEndPlugin<void> = {
   id: 'skillsnetwork-authoring-extension:menu',
@@ -61,18 +59,7 @@ export const menu: JupyterFrontEndPlugin<void> = {
           show_spinner('Loading up your lab...');
 
           const token = tokenInput.value
-          let {instructions_file_path, body: instructions_content} = await getLabModel(axiosHandler(token))
-          const labFilename = getLabFileName(instructions_file_path);
-
-          // Attempt to open the lab
-          const nbPanel = docManager.createNew(labFilename, 'notebook', { name:  Globals.PY_KERNEL_NAME}) as NotebookPanel;
-
-          if (nbPanel === undefined) {
-            throw Error('Error loading lab')
-          }
-          loadLabContents(nbPanel, JSON.parse(instructions_content) as unknown as nbformat.INotebookContent);
-          Globals.TOKEN = tokenInput.value;
-          sessionStorage.setItem('atlas_token', Globals.TOKEN);
+          await openLab(token, docManager);
         }
       })
       .catch((e) => {
